# TU TISS plugin for LDAP User Managment Tools

[ "$0" != "${BASH_SOURCE[0]}" ] || {
    echo "$0: this script must be sourced, not called" >&2
    exit 1
}

# plugin_interactive_resolve <ret-dict-vn> <key> <attribute> [..]
# errors: 92 (no interactive terminal), 93 (aborted on users request)
function plugin_interactive_resolve() {
    (( $# > 2 )) || bb_fatal "plugin_interactive_resolve called with $#" \
	"instead of 3 or more args"

    local _ret_dict_vn="$1"
    local _key="$2"
    shift 2

    [ -t 0 ] || {
	bb_msg err "plugin_interactive_resolve can not be used from non" \
	    "interactive terminal, aborting"
	return 92
    }

    local -n _ret_dict_ref="$_ret_dict_vn"

    # clear destination array
    _ret_dict_ref=()

    while true
    do
	echo "Interactive resolver will now read $# attributes for key: $_key"

	local _attr _value
	for _attr in "$@"
	do
	    echo -n "Enter value for attribute $_attr: "
	    read -r _value

	    _ret_dict_ref["$_attr"]="$_value"
	done

	while true
	do
	    echo -n 'Done. Are you happy with your inputs [y(es)|n(o)|a(bort)]: '
	    read -r _value
	    case "$_value" in
		y|yes) return 0;;
		n|no) continue 2;;
		a|abort)
		    bb_msg err "Interactive resolver (key=$_key) aborted" \
			"on users request"
		    return 93
		    ;;
		*) echo "Illegal input ($_value), try again!"
	    esac
	done

    done
}
